@@ -23,7 +23,7 @@ def CompleteRun():
     a = ParametersLEDET()
     a.readLEDETExcel(testfile8)
     Sw = MinMaxSweep(a, 6)
-    MagnetName = 'MCBXH_CopperWedges_ThCool'
+    MagnetName = 'MCBXV_CopperWedges_ThCool'
 
     ##8mag
     # Sw.addParameterToSweep('l_magnet', 2.56, 4.8)
@@ -52,8 +52,8 @@ def CompleteRun():
     # Sw.addQuenchSweep("tStartQuench",[1,1,1,1,1,1],[-0.2, -0.21, -0.22, -0.23, -0.24, -0.25])
 
     ## MCBXH_CopperWedges -2
-    Sw.addQuenchSweep("tStartQuench", [[1, 890],[121,1010],[289,1178],[393,1282],[1330,441],[1450,561],[1618,729],[1722,833]],
-                      [[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182],[-0.2, -0.182]])
+    Sw.addQuenchSweep("tStartQuench", [[1, 890],[393,1282],[1, 890],[393,1282],[1, 890],[393,1282],[1, 890],[393,1282]],
+                      [[-0.2, -0.182],[-0.2, -0.182],[-0.15, -0.132],[-0.15, -0.132],[-0.1, -0.082],[-0.2, -0.082],[-0.05, -0.032],[-0.05, -0.032]])
 
     Sw.generatePermutations()
     end = time.time()
@@ -70,7 +70,7 @@ def CompleteRun():
     print("Time:", end - start)
     print("Preparation done")
 
-    RunSimulations(ledetFolder, ledetExe, 'MCBXH_CopperWedges_ThCool', RunSimulations=False)
+    RunSimulations(ledetFolder, ledetExe, 'MCBXV_CopperWedges_ThCool', RunSimulations=True)
     # EvaluateSimulations("C:\\cernbox\\LEDET\\LEDET\\MCO\\Output\\Txt Files", 'MCO',
     #                     'C:\\cernbox\\Validation_MCDO\\Exp Data\\RCO.A56B1_2018-03-16_PM_I_A_AutoAlign.csv',
     #                     Sw, Mat=False, SkipAlign=True)
@@ -91,6 +91,9 @@ def CompleteRun():
     # EvaluateSimulations('C:\\cernbox\\Validation_MCBX_HV\\LEDET Validation\\2nd Sweep-RRR_fro_tQ_THCOOL\\Output\\Txt Files',
     #                     'MCBXH_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
     #                      Sw, Mat=False, showBestFit = 20)
+    # EvaluateSimulations('C:\\cernbox\\LEDET\\LEDET\\MCBXV_CopperWedges_ThCool\\Output\\Txt Files',
+    #                     'MCBXV_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXV2.R1_2017-04-20_PM_I_ARAW.csv',
+    #                      Sw, Mat=False, showBestFit = 20)
 
 def AutomaticRun():
     LEDETFolder = 'C:\\cernbox\LEDET\\LEDET_SimulationFiles_Quench'
