@@ -3,7 +3,6 @@ import json
 import pandas as pd
 import numpy as np
 import shutil
-import earthpy as et
 
 from steam_nb_api.resources.ResourceReader import ResourceReader
 from steam_nb_api.utils.misc import makeCopyFile
@@ -384,8 +383,10 @@ class ParametersCOSIM:
         for n in range(0, N_LEDET):
             if DistinctMagnets != 1:
                 DM = n+1
+                M_add = "M"+str(DM)
             else:
                 DM = 1
+                M_add = ''
             for i in range(len(CoilSections)):  # Number of Ports
                 for j in range(2):  # 2Ports in PSpice
                     struct = {}
@@ -400,9 +401,9 @@ class ParametersCOSIM:
                                 cPPSpice = "V"
                             else:
                                 cPPSpice = couplingParameterPSpice[j][0][l][0]
-                            substruct_in["labels"] = [cPPSpice + "_field_" + str(i+1) + "_stim"]  # First Port for Field
+                            substruct_in["labels"] = [cPPSpice + "_field_"+M_add + str(i+1) + "_stim"]  # First Port for Field
                         else:  # Second Port with circuit
-                            substruct_in["labels"] = ["V_circuit_" + str(i+1) + "_stim"]
+                            substruct_in["labels"] = ["V_circuit_" +M_add+ str(i+1) + "_stim"]
                         substruct_in["types"] = couplingParameterPSpice[j][0][l][1]
                         struct["inputs"].append(substruct_in)
 
@@ -430,7 +431,6 @@ class ParametersCOSIM:
                 f.write('\n')
 
     def copyCOSIMfiles(self, circuit, nameFileSING, StimulusFile, LEDETFiles, nameMagnet,N_LEDET=1):
-        print(et.io.HOME)
         nameFolderCosimModel = os.path.join(os.getcwd(), 'cosim_model_' + circuit)
         print(nameFolderCosimModel)
         # Copy PSPICE model file
